@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 BEGIN {
-	our $VERSION = 'v0.1.6'; # VERSION
+	our $VERSION = '0.1.7'; # VERSION
 }
 use Moose;
 use namespace::autoclean;
@@ -18,6 +18,10 @@ use Business::CyberSource::Response;
 
 use SOAP::Lite; #+trace => [ 'debug' ] ;
 
+has '+_trait_namespace' => (
+	default => 'Business::CyberSource::Request::Role',
+);
+
 has request_id => (
 	is  => 'ro',
 	isa => 'Str',
@@ -116,6 +120,7 @@ __PACKAGE__->meta->make_immutable;
 
 # ABSTRACT: CyberSource Credit Request Object
 
+
 __END__
 =pod
 
@@ -125,7 +130,61 @@ Business::CyberSource::Request::Credit - CyberSource Credit Request Object
 
 =head1 VERSION
 
-version v0.1.6
+version 0.1.7
+
+=head1 SYNOPSIS
+
+	use Business::CyberSource::Request::Credit;
+
+	my $req = Business::CyberSource::Request::Credit
+		->with_traits(qw{
+			BillingInfo
+			CreditCardInfo
+		})
+		->new({
+			username       => 'merchantID',
+			password       => 'transaction key',
+			production     => 0,
+			reference_code => 'merchant reference code',
+			first_name     => 'Caleb',
+			last_name      => 'Cushing',
+			street         => 'somewhere',
+			city           => 'Houston',
+			state          => 'TX',
+			zip            => '77064',
+			country        => 'US',
+			email          => 'xenoterracide@gmail.com',
+			total          => 5.00,
+			currency       => 'USD',
+			credit_card    => '4111-1111-1111-1111',
+			cc_exp_month   => '09',
+			cc_exp_year    => '2025',
+		});
+
+	my $res = $req->submit;
+
+=head1 DESCRIPTION
+
+This object allows you to create a request for a credit. Their are two types
+of credits, a standalone credit, and a follow on credit.
+
+=head1 METHODS
+
+=head2 with_traits
+
+For standalone credit requests requests you need to apply C<BillingInfo> and
+C<CreditCardInfo> roles. This is not necessary for follow on credits. Follow
+on credits require that you specify a C<request_id> in order to work.
+
+=head2 new
+
+Instantiates a credit request object, see L<the attributes listed below|/ATTRIBUTES>
+for which ones are required and which are optional.
+
+=head2 submit
+
+Actually sends the required data to CyberSource for processing and returns a
+L<Business::CyberSource::Response> object.
 
 =head1 ATTRIBUTES
 
@@ -225,75 +284,13 @@ Type: Str
 
 This attribute is required.
 
-=head1 METHODS
+=head1 SEE ALSO
 
-=head2 submit
+=over
 
-Method originates in Business::CyberSource::Request::Credit.
+=item * L<Business::CyberSource::Request>
 
-=head2 client_env
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 currency
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 password
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 production
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 server
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 request_id
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 new
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 with_traits
-
-Method originates in MooseX::Traits.
-
-=head2 new_with_traits
-
-Method originates in MooseX::Traits.
-
-=head2 total
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 username
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 apply_traits
-
-Method originates in MooseX::Traits.
-
-=head2 reference_code
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 client_name
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 foreign_currency
-
-Method originates in Business::CyberSource::Request::Credit.
-
-=head2 client_version
-
-Method originates in Business::CyberSource::Request::Credit.
+=back
 
 =head1 BUGS
 
